@@ -14,6 +14,7 @@ from collections import Counter
 import enum
 import operator
 import unittest
+from typing import cast
 
 from music21 import base
 from music21 import exceptions21
@@ -245,6 +246,7 @@ class StreamAligner:
         if self.m == 0:
             raise AlignerException('Cannot perform alignment with empty source stream.')
 
+        # noinspection PyProtectedMember
         if 'numpy' in base._missingImport:
             raise AlignerException('Cannot run Aligner without numpy.')
         import numpy as np
@@ -328,15 +330,15 @@ class StreamAligner:
                                                   self.hashedSourceStream[j - 1])
 
                 previousValues = [self.distanceMatrix[i - 1][j] + insertCost,
-                                   self.distanceMatrix[i][j - 1] + deleteCost,
-                                   self.distanceMatrix[i - 1][j - 1] + substCost]
+                                  self.distanceMatrix[i][j - 1] + deleteCost,
+                                  self.distanceMatrix[i - 1][j - 1] + substCost]
 
                 self.distanceMatrix[i][j] = min(previousValues)
 
     def getPossibleMovesFromLocation(self, i, j):
         # noinspection PyShadowingNames
         '''
-        i and j are current row and column index in self.distanceMatrix
+        i and j are current row and column indices in self.distanceMatrix
         returns all possible moves (0 up to 3)
         vertical, horizontal, diagonal costs of adjacent entries in self.distMatrix
 
@@ -383,9 +385,9 @@ class StreamAligner:
         [0, None, None]
 
         '''
-        verticalCost = self.distanceMatrix[i - 1][j] if i >= 1 else None
-        horizontalCost = self.distanceMatrix[i][j - 1] if j >= 1 else None
-        diagonalCost = self.distanceMatrix[i - 1][j - 1] if (i >= 1 and j >= 1) else None
+        verticalCost = int(self.distanceMatrix[i - 1][j]) if i >= 1 else None
+        horizontalCost = int(self.distanceMatrix[i][j - 1]) if j >= 1 else None
+        diagonalCost = int(self.distanceMatrix[i - 1][j - 1]) if (i >= 1 and j >= 1) else None
 
         possibleMoves = [verticalCost, horizontalCost, diagonalCost]
         return possibleMoves
@@ -746,7 +748,7 @@ class StreamAligner:
 
     def calculateChangesList(self):
         '''
-        Traverses through self.distanceMatrix from bottom right corner to top left looking at
+        Traverses through self.distanceMatrix from the bottom right corner to top left looking at
         bestOp at every move to determine which change was most likely at any point. Compiles
         the list of changes in self.changes. Also calculates some metrics like self.similarityScore
         and self.changesCount.
@@ -862,7 +864,7 @@ class StreamAligner:
             raise AlignmentTracebackException('Traceback of best alignment did not end properly')
 
         self.changesCount = Counter(elem[2] for elem in self.changes)
-        self.similarityScore = float(self.changesCount[ChangeOps.NoChange]) / len(self.changes)
+        self.similarityScore = self.changesCount[ChangeOps.NoChange] / len(self.changes)
 
     def showChanges(self, show=False):
         '''
@@ -1051,11 +1053,12 @@ class Test(unittest.TestCase):
 
     def testShowInsertion(self):
         '''
-        two streams:
-        MIDI is CCCB
-        OMR is CCC
+        Given two streams:
 
-        Therefore there needs to be an insertion to get from OMR to MIDI
+        MIDI is `C C C B`
+        OMR is `C C C`
+
+        Therefore, there needs to be an insertion to get from OMR to MIDI
         '''
         from music21 import stream
         from music21 import note
@@ -1078,20 +1081,27 @@ class Test(unittest.TestCase):
         sa.align()
         sa.showChanges()
 
-        self.assertEqual(target.getElementById(sa.changes[3][0].id).style.color, 'green')
-        self.assertEqual(target.getElementById(sa.changes[3][0].id).lyric, '3')
-        self.assertEqual(source.getElementById(sa.changes[3][1].id).style.color, 'green')
-        self.assertEqual(source.getElementById(sa.changes[3][1].id).lyric, '3')
+        n0 = target.getElementById(sa.changes[3][0].id)
+        self.assertIsNotNone(n0)
+        n0 = cast(note.Note, n0)
+        self.assertEqual(n0.style.color, 'green')
+        self.assertEqual(n0.lyric, '3')
+
+        n1 = source.getElementById(sa.changes[3][1].id)
+        self.assertIsNotNone(n1)
+        n1 = cast(note.Note, n1)
+        self.assertEqual(n1.style.color, 'green')
+        self.assertEqual(n1.lyric, '3')
 
     def testShowDeletion(self):
         '''
-        two streams:
+        Given two streams:
 
-        MIDI is `CCC`
+        MIDI is `C C C`
 
-        OMR is `CCCB`
+        OMR is `C C C B`
 
-        Therefore there needs to be a deletion to get from OMR to MIDI.
+        Therefore, there needs to be a deletion to get from OMR to MIDI.
         '''
         from music21 import stream
         from music21 import note
@@ -1114,18 +1124,25 @@ class Test(unittest.TestCase):
         sa.align()
         sa.showChanges()
 
-        self.assertEqual(target.getElementById(sa.changes[3][0].id).style.color, 'red')
-        self.assertEqual(target.getElementById(sa.changes[3][0].id).lyric, '3')
-        self.assertEqual(source.getElementById(sa.changes[3][1].id).style.color, 'red')
-        self.assertEqual(source.getElementById(sa.changes[3][1].id).lyric, '3')
+        n0 = target.getElementById(sa.changes[3][0].id)
+        self.assertIsNotNone(n0)
+        n0 = cast(note.Note, n0)
+        self.assertEqual(n0.style.color, 'red')
+        self.assertEqual(n0.lyric, '3')
+
+        n1 = source.getElementById(sa.changes[3][1].id)
+        self.assertIsNotNone(n1)
+        n1 = cast(note.Note, n1)
+        self.assertEqual(n1.style.color, 'red')
+        self.assertEqual(n1.lyric, '3')
 
     def testShowSubstitution(self):
         '''
         two streams:
-        MIDI is CCC
-        OMR is CCB
+        MIDI is `C C C`
+        OMR is `C C B`
 
-        Therefore there needs to be a substitution to get from OMR to MIDI
+        Therefore, there needs to be a substitution to get from OMR to MIDI
         '''
         from music21 import stream
         from music21 import note
@@ -1147,10 +1164,18 @@ class Test(unittest.TestCase):
         sa.align()
         sa.showChanges()
 
-        self.assertEqual(target.getElementById(sa.changes[2][0].id).style.color, 'purple')
-        self.assertEqual(target.getElementById(sa.changes[2][0].id).lyric, '2')
-        self.assertEqual(source.getElementById(sa.changes[2][1].id).style.color, 'purple')
-        self.assertEqual(source.getElementById(sa.changes[2][1].id).lyric, '2')
+
+        n0 = target.getElementById(sa.changes[2][0].id)
+        self.assertIsNotNone(n0)
+        n0 = cast(note.Note, n0)
+        self.assertEqual(n0.style.color, 'purple')
+        self.assertEqual(n0.lyric, '2')
+
+        n1 = source.getElementById(sa.changes[2][1].id)
+        self.assertIsNotNone(n1)
+        n1 = cast(note.Note, n1)
+        self.assertEqual(n1.style.color, 'purple')
+        self.assertEqual(n1.lyric, '2')
 
 
 if __name__ == '__main__':
